@@ -11,4 +11,5 @@ from .qctests import *  # noqa: F403
 from .radiometer_tests import *  # noqa: F403
 from .bsrn_tests import *  # noqa: F403
 from .comparison_tests import *  # noqa: F403
-from .sp2 import SP2ParticleCriteria, get_waveform_statistics
+from .add_supplemental_qc import *  # noqa: F403
+from .sp2 import SP2ParticleCriteria, get_waveform_statistics  # noqa: F403
